# -*- coding: utf-8 -*-
# @Time    : 2020/12/19 4:14 下午
# @Author  : haohao
# @FileName: test_case1.py

# content of test_sample.py


class learnPack:
    def learnpack(self,a):
        print(a)

if __name__ == "__main__":
    # pytest.main(["-s", "test_case1.py"])
    learnPack().learnpack('type1')


# -*- coding: utf-8 -*-
# @Time    : 2021/1/13 4:42 下午
# @Author  : haohao
# @FileName: setup.py
from setuptools import find_packages,setup

setup(
    name='learnpack',
    version='1.0.3',
    author='haohao',
    packages = find_packages(),
)